結果
| 問題 | No.1012 荷物収集 |
| コンテスト | |
| ユーザー |
amyu
|
| 提出日時 | 2020-03-20 22:30:12 |
| 言語 | Python3 (3.15.0 + numpy 2.5.4 + scipy 1.18.1 + ACL) |
| 結果 |
AC
不安定
|
| 実行時間 | 378 ms / 2,000 ms |
| + 22µs | |
| コード長 | 357 bytes |
| 記録 | |
| コンパイル時間 | 53 ms |
| コンパイル使用メモリ | 14,976 KB |
| 実行使用メモリ | 44,460 KB |
| 最終ジャッジ日時 | 2026-10-03 22:00:23 |
| 合計ジャッジ時間 | 13,057 ms |
|
ジャッジサーバーID (参考情報) |
judge4_0 / judge1_0 |
(要ログイン)
| ファイルパターン | 結果 |
|---|---|
| sample | AC * 4 |
| other | AC * 41 |
ソースコード
import sys
input=sys.stdin.readline
from bisect import bisect
n,q=map(int,input().split())
l=[tuple(map(int,input().split())) for i in range(n)]
l.sort()
aw=[0]
axw=[0]
for x,w in l:
aw.append(aw[-1]+w)
axw.append(axw[-1]+x*w)
x=list(map(int,input().split()))
for i in x:
t=bisect(l,(i,0))
print(i*aw[t]-axw[t]+axw[n]-axw[t]-i*(aw[n]-aw[t]))
amyu